@@ -19,30 +19,33 @@ if TYPE_CHECKING:
     from .paramtable import ParamTable
     from .session import Session
 
-__all__ = ['AbstrSynth', 'Synth', 'SynthGroup']
+
+__all__ = (
+    'AbstrSynth',
+    'Synth',
+    'SynthGroup'
+)
 
 
 class AbstrSynth(baseevent.BaseEvent):
     """
     A base class for Synth and SynthGroup
 
-    Attributes:
-        engine (Engine): the Engine which scheduled this synth
-        autostop (bool): stop the underlying csound synth when this object
-            is deleted
-        priority (int): the priority at which this synth was scheduled
     """
     __slots__ = ('engine', 'autostop', 'priority')
 
     def __init__(self, p1: float, start: float, dur: float,
                  engine: Engine, autostop: bool = False, priority: int = 1):
         super().__init__(p1, start, dur, ())
-        self.p1 = p1
-        self.start = start
-        self.dur = dur
+
         self.engine: Engine = engine
+        "The engine used to schedule this synth"
+
         self.autostop: bool = autostop
+        "If True, stop the underlying csound synth when this object is deleted"
+
         self.priority: int = priority
+        "The priority of this synth. Lower priorities are evaluated first in the chain"
 
     def __del__(self):
         try:
@@ -105,7 +108,7 @@ class AbstrSynth(baseevent.BaseEvent):
 
         .. seealso::
 
-            * :meth:`~AbstractSynth.set`
+            * :meth:`~AbstrSynth.set`
 
         Example
         =======
@@ -123,7 +126,7 @@ class AbstrSynth(baseevent.BaseEvent):
         """
         raise NotImplementedError()
 
-    def get(self, slot: Union[int, str], default: float = None) -> Optional[float]:
+    def get(self, slot: Union[int, str], default: float = None) -> float | None:
         """
         Get the value of a named parameter
 
@@ -141,18 +144,18 @@ class AbstrSynth(baseevent.BaseEvent):
         """
         raise NotImplementedError()
 
-    def tableParams(self) -> Optional[Set[str]]:
+    def tableParams(self) -> Set[str] | None:
         """
-        Return a set of all named parameters
+        Return a set of all named table parameters
 
         Returns None if this synth does not have a parameters table
 
         .. seealso::
 
-            * :meth:`~AbstractSynth.automateTable`
-            * :meth:`~AbstractSynth.hasParamTable`
-            * :meth:`~AbstractSynth.tableState`
-            * :meth:`~AbstractSynth.namedPfields`
+            * :meth:`~AbstrSynth.automateTable`
+            * :meth:`~AbstrSynth.hasParamTable`
+            * :meth:`~AbstrSynth.tableState`
+            * :meth:`~AbstrSynth.namedPfields`
 
         """
         raise NotImplementedError()
@@ -170,7 +173,7 @@ class AbstrSynth(baseevent.BaseEvent):
         """ Does this synth/group have an associated parameter table?"""
         raise NotImplementedError()
 
-    def paramMode(self) -> Optional[str]:
+    def paramMode(self) -> str | None:
         """
         Returns the dynamic parameter mode, or None
 
@@ -197,23 +200,24 @@ class AbstrSynth(baseevent.BaseEvent):
 
         .. seealso::
 
-            * :meth:`~AbstractSynth.set`
-            * :meth:`~AbstractSynth.get`
+            * :meth:`~AbstrSynth.set`
+            * :meth:`~AbstrSynth.get`
 
         """
         raise NotImplementedError()
 
-    def namedPfields(self) -> Optional[Set[str]]:
+    def namedPfields(self) -> Set[str] | None:
         """
         Returns a set of all named pfields
         """
         raise NotImplementedError()
 
-    def namedParams(self) -> Optional[Set[str]]:
+    def namedParams(self) -> Set[str] | None:
         """
         Returns a set of named parameters, or None if this Synth has no named parameters
 
-        These parameters can be modified via :meth:`~AbstractSynth.set` or :meth:`~AbstractSynth.automate`
+        These parameters can be modified via :meth:`~AbstrSynth.set` or
+        :meth:`~AbstrSynth.automate`
         """
         mode = self.paramMode()
         if mode == 'parg':
@@ -249,7 +253,7 @@ class AbstrSynth(baseevent.BaseEvent):
         Returns:
             a Synth representing the automation routine
 
-        .. seealso:: :meth:`~AbstractSynth.setp`, :meth:`~AbstractSynth.automate`
+        .. seealso:: :meth:`~AbstrSynth.setp`, :meth:`~AbstrSynth.automate`
         """
         raise NotImplementedError()
 
@@ -257,7 +261,7 @@ class AbstrSynth(baseevent.BaseEvent):
         """
         Modify the value of a pfield.
 
-        .. seealso:: :meth:`~AbstractSynth.automatep`
+        .. seealso:: :meth:`~AbstrSynth.automatep`
         """
         raise NotImplementedError()
 
@@ -278,6 +282,7 @@ _synthStatusIcon = {
 
 class Synth(AbstrSynth):
     """
+    A Synth represents one running csound event
 
     Args:
         engine: the engine instance where this synth belongs to
@@ -292,17 +297,6 @@ class Synth(AbstrSynth):
             scope or is deleted, the underlying note is unscheduled
         table: an associated Table (if needed)
 
-    Attributes:
-        synthid: the synth id inside csound (p1, a fractional instrument number)
-        engine: the engine instance where this synth belongs to
-        synthid: the synth id inside csound (p1, a fractional instrument number)
-        instr: the Instr which originated this Synth
-        startTime: when was this synth started
-        dur: duration of the note (can be -1 for infinite)
-        args: the pfields used to create this synth, starting at p4
-        synthGroup: the group this synth belongs to (if any)
-        table (ParamTable): an associated Table (if defined)
-
     Example
     =======
 
@@ -343,15 +337,19 @@ class Synth(AbstrSynth):
         __slots__ = ('instr', 'table', 'group', '_playing')
 
         AbstrSynth.__init__(self, p1=p1, start=start, dur=dur, engine=engine, autostop=autostop, priority=priority)
+
         self.instr: Instr = instr
         """The Instr used to play this synth"""
 
-        self.table: Optional[ParamTable] = table
+        self.table: ParamTable | None = table
         """A ParamTable used to define parameters if using a table"""
 
         self.group = synthgroup
-        """"""
+        """The group this synth belongs to, if any"""
+
         self.args = args
+        """The args used to schedule this synth"""
+
         self._playing: bool = True
 
     def _html(self) -> str:
@@ -455,12 +453,12 @@ class Synth(AbstrSynth):
     def finished(self) -> bool:
         return self.playStatus() == 'stopped'
 
-    def tableState(self) -> Optional[dict[str, float]]:
+    def tableState(self) -> dict[str, float] | None:
         if self.table is None:
             return None
         return self.table.asDict()
 
-    def tableParams(self) -> Optional[Set[str]]:
+    def tableParams(self) -> Set[str] | None:
         if self.table is None:
             return None
         return set(self.table.mapping.keys())
@@ -627,7 +625,7 @@ class Synth(AbstrSynth):
             # are assigned a widget
             synth.ui(kampdb=(-48, 0), kres=(0, 1))
 
-        .. figure:: ../assets/synthui.png
+        .. figure:: assets/synthui.png
 
         .. seealso::
 
